@@ -28,6 +28,11 @@ typedef struct _zend_stack {
 
 #define STACK_BLOCK_SIZE 16
 
+typedef enum {
+	ZEND_STACK_APPLY_TOPDOWN,
+	ZEND_STACK_APPLY_BOTTOMUP,
+} zend_stack_apply_direction;
+
 BEGIN_EXTERN_C()
 ZEND_API void zend_stack_init(zend_stack *stack, int size);
 ZEND_API int zend_stack_push(zend_stack *stack, const void *element);
@@ -39,11 +44,8 @@ ZEND_API void zend_stack_destroy(zend_stack *stack);
 ZEND_API void *zend_stack_base(const zend_stack *stack);
 ZEND_API int zend_stack_count(const zend_stack *stack);
 ZEND_API void zend_stack_apply(zend_stack *stack, int type, int (*apply_function)(void *element));
-ZEND_API void zend_stack_apply_with_argument(zend_stack *stack, int type, int (*apply_function)(void *element, void *arg), void *arg);
-ZEND_API void zend_stack_clean(zend_stack *stack, void (*func)(void *), zend_bool free_elements);
+ZEND_API void zend_stack_apply_with_argument(zend_stack *stack, zend_stack_apply_direction type, int (*apply_function)(void *element, void *arg), void *arg);
+ZEND_API void zend_stack_clean(zend_stack *stack, void (*func)(void *), bool free_elements);
 END_EXTERN_C()
 
-#define ZEND_STACK_APPLY_TOPDOWN	1
-#define ZEND_STACK_APPLY_BOTTOMUP	2
-
 #endif /* ZEND_STACK_H */
